#
# spec file for package talosctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           talosctl
Version:        1.7.1
Release:        1.0.2.1.sr20240429
Summary:        CLI to interact with Talos Linux
License:        MPL-2.0
URL:            https://github.com/siderolabs/talos
Source:         talos-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.22

%description
Talos Linux is a modern Linux distribution built for Kubernetes.
The talosctl tool acts as a reference implementation for the Talos API, but it also handles a lot of conveniences for the use of Talos and its clusters.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1 -n talos-%{version}

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags=" -X github.com/siderolabs/talos/pkg/machinery/gendata.VersionSHA=v%{version} -X github.com/siderolabs/talos/pkg/version.Built=$BUILD_DATE" \
   -o bin/talosctl ./cmd/talosctl

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Thu May  2 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.7.1:
  Changelog for Talos 1.7.1 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.7.1
  Apparently no changes regarding the CLI
* Fri Apr 19 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.7.0
  Welcome to the v1.7.0 release of Talos!
  https://www.talos.dev/v1.7/introduction/what-is-new/
- do not strip aka remove -s -w ldflags
* Thu Mar 21 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.6.7:
  Changelog for Talos 1.6.7 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.7
  CLI-related changes:
  * 2c9159977 fix: patch correctly config in talosctl upgrade-k8s
* Sun Mar 17 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.6.6:
  Changelog for Talos 1.6.6 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.6
  Apparently no changes regarding the CLI
* Sat Feb 24 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 1.6.5:
  Changelog for Talos 1.6.5 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.5
  Apparently no changes regarding the CLI
- BuildRequire go1.22
* Thu Feb  1 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to 1.6.4:
  Changelog for Talos 1.6.4 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.4
  Apparently no changes regarding the CLI
- Update to 1.6.3:
  Changelog for Talos 1.6.3 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.3
  Apparently no changes regarding the CLI
* Thu Jan 18 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to 1.6.2:
  Changelog for Talos 1.6.2 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.2
  Apparently no changes regarding the CLI
* Sun Jan  7 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- Update to 1.6.1:
  Changelog for Talos 1.6.1 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.1
  Apparently no changes regarding the CLI
* Fri Dec 15 2023 kastl@b1-systems.de
- Update to version 1.6.0:
  Changelog for Talos 1.6.0 is here:
  https://github.com/siderolabs/talos/releases/tag/v1.6.0
  Changes for the CLI:
  * The command 'images' deprecated in Talos 1.5 was removed,
    please use 'talosctl images default' instead.
* Thu Nov  9 2023 kastl@b1-systems.de
- Update to version 1.5.5:
  * release(v1.5.5): prepare release
  * fix: don't validate machine.install if installed
  * fix: when writing to META in the installer/imager, use fixed
    name
  * fix: fix error output of cli action tracker
  * feat: update etcd to 3.5.10
  * chore: bump go-api-signature dependency to v0.3.1
  * fix: make Talos work on Rockpi 4c boards again
  * feat: update Go 1.20.11, Linux 6.1.61, Kubernetes 1.28.3
  * fix: update gRPC library to 1.57.2
* Mon Jul 17 2023 Johannes Kastl <kastl@b1-systems.de>
- new package talosctl
